@@ -1,5 +1,4 @@
-"""
-An ultra fast cross-platform multiple screenshots module in pure python
+"""An ultra fast cross-platform multiple screenshots module in pure python
 using ctypes.
 
 This module is maintained by Mickaël Schoentgen <contact@tiger-222.fr>.
@@ -8,13 +7,15 @@ You can always get the latest version of this module at:
     https://github.com/BoboTiG/python-mss
 If that URL should fail, try contacting the author.
 """
-from .exception import ScreenShotError
-from .factory import mss
 
-__version__ = "7.0.1"
-__author__ = "Mickaël 'Tiger-222' Schoentgen"
-__copyright__ = """
-Copyright (c) 2013-2022, Mickaël 'Tiger-222' Schoentgen
+from mss.exception import ScreenShotError
+from mss.factory import mss
+
+__version__ = "10.1.0"
+__author__ = "Mickaël Schoentgen"
+__date__ = "2013-2025"
+__copyright__ = f"""
+Copyright (c) {__date__}, {__author__}
 
 Permission to use, copy, modify, and distribute this software and its
 documentation for any purpose and without fee or royalty is hereby
